/************************************************************************************************

 Author        : ADI - Apps            www.analog.com/AduC7060

 Date          : November 2007

 File          : ADC1_Cont.c

 Hardware      : ADuC706x

 Description   : This Simple ADC1 example shows how to initialize the Auxiliary ADC for 
 			continuous sampling using a Single-Ended inputs.
*************************************************************************************************/
// Bit Definitions
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000
#define BIT14 0x4000
#define BIT15 0x8000


#include<aduc7060.h>
# include "stdio.h"
# include "string.h"

volatile unsigned char bSendResultToUART = 0;	// Flag used to indicate ADC1 resutl ready to send to UART	
unsigned char szTemp[16] = "";					// Used to store ADC1 result before printing to UART
unsigned char ucTxBufferEmpty  = 0;				// Used to indicate that the UART Tx buffer is empty
volatile unsigned long ulADC1Result = 0;		// Variable that ADC1DAT is read into in ADC1 IRQ

int main(void)
{
    unsigned char i = 0;
    unsigned char nLen = 0;
	
	POWKEY1 = 0x1;
	POWCON0 = 0x78;		   // Set core to max CPU speed of 10.24Mhz
	POWKEY2 = 0xF4;
	
	// Initialize the UART for 9600-8-N
	GP1CON = BIT0 + BIT4;  // Select UART functionality for P1.0/P1.1
	COMCON0 = BIT7;			// Enable access to COMDIV registers
	COMDIV0 = 0x21;			// Set baud rate to 9600.
	COMDIV1 = 0x00;

	COMCON0 = BIT0 + BIT1 + BIT2;
	COMIEN0 = BIT0 + BIT1;	 // Enable UART interrupts when Rx full and Tx buffer empty.
	
	
	// Configure ADC1 for continuous conversions, 1khz, ADC4 input
	ADCMSKI = BIT1;	// Enable ADC1 result ready interrupt source
  	ADCFLT = 0x7;	// Chop off, 1Khz samping rate, SF = 7.	No averaging
  	ADCMDE = BIT0;	// Continuous Conversion mode, Normal mode
  	ADC1CON = BIT8 + BIT9 	// ADC1 input channel 4 in Single-Ended mode.
			+ BIT15;	    // Auxiliary-ADC Enabled
									// Also, Int reference, 
	ADCCFG = 0;
	IRQEN = BIT10 + BIT11; // Enable ADC1 and UART interrupts
	bSendResultToUART = 0;
	while (1)
	{
	   if (bSendResultToUART == 1) // Is there an ADC1 result ready for UART transmission?
	   {	
	   		sprintf ( (char*)szTemp, "%lu\r",ulADC1Result );// Send the ADC1 Result to the UART                          
   			nLen = strlen((char*)szTemp);
     		for ( i = 0 ; i < nLen ; i++ )	// loop to send ADC1 result
   			{
	     		 COMTX = szTemp[i];
	      		 ucTxBufferEmpty = 0;
		  		 while (ucTxBufferEmpty == 0)
	      		 {
	      		 }
			}
   		}
	}
}

void IRQ_Handler(void) __irq
{
	unsigned long IRQSTATUS = 0;
	unsigned char ucCOMIID0 = 0;

	IRQSTATUS = IRQSTA;	   // Read off IRQSTA register
	if ((IRQSTATUS & BIT11) == BIT11)	//UART interrupt source
	{
		ucCOMIID0 = COMIID0;
		if ((ucCOMIID0 & 0x2) == 0x2)	  // Transmit buffer empty
		{
		  ucTxBufferEmpty = 1;
		} 	
	}

	if ((IRQSTATUS & BIT10) == BIT10)	//If ADC1 interrupt source
	{
	  	ulADC1Result = ADC0DAT;	// Read ADC0 conversion result
		ulADC1Result = ADC1DAT;	// Read ADC1 conversion result
		bSendResultToUART = 1;
	}
}


